@@ -36,6 +36,8 @@ import aws_cdk.aws_codepipeline as _aws_cdk_aws_codepipeline_ceddda9d
 import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
 import aws_cdk.aws_ecr as _aws_cdk_aws_ecr_ceddda9d
 import aws_cdk.aws_ecs as _aws_cdk_aws_ecs_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
 import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
 import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
 import constructs as _constructs_77d1e7e8
@@ -452,6 +454,127 @@ class ContainerImagePipelineProps:
         )
 
 
+class FunctionCodeUpdater(
+    _constructs_77d1e7e8.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="shady-island.automation.FunctionCodeUpdater",
+):
+    '''Automates deployments of Lambda function code.
+
+    In order to guarantee the least amount of privilege to the principal sending
+    new code revisions to S3 (e.g. a GitHub Action, a CodeBuild project), you can
+    use this construct to call the ``UpdateFunctionCode`` action of the Lambda API
+    any time a new revision is added to a bucket (which must support versioning).
+    '''
+
+    def __init__(
+        self,
+        scope: _constructs_77d1e7e8.Construct,
+        id: builtins.str,
+        *,
+        bucket: _aws_cdk_aws_s3_ceddda9d.IBucket,
+        object_key: builtins.str,
+        target: _aws_cdk_aws_lambda_ceddda9d.IFunction,
+    ) -> None:
+        '''Creates a new FunctionCodeUpdater.
+
+        :param scope: - The scope in which to define this construct.
+        :param id: - The scoped construct ID.
+        :param bucket: The bucket to monitor for changes.
+        :param object_key: The object within the bucket to monitor (e.g. my-application/code.zip).
+        :param target: The Lambda function to update.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f33a0905023521597d28cee93114601f3e35da34b9eff4df0ee5fd59350ad1e3)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+        props = FunctionCodeUpdaterProps(
+            bucket=bucket, object_key=object_key, target=target
+        )
+
+        jsii.create(self.__class__, self, [scope, id, props])
+
+    @jsii.member(jsii_name="grantPutCode")
+    def grant_put_code(
+        self,
+        identity: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+    ) -> _aws_cdk_aws_iam_ceddda9d.Grant:
+        '''Grants ``s3:PutObject*`` and ``s3:AbortObject*`` permissions for the S3 object key of the Lambda function code.
+
+        If encryption is used, permission to use the key to encrypt uploaded files
+        will also be granted to the same principal.
+
+        :param identity: - The principal.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8dbf24b39a405557c0b908319842dd0572a414219a6984055ab05854fb4231eb)
+            check_type(argname="argument identity", value=identity, expected_type=type_hints["identity"])
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Grant, jsii.invoke(self, "grantPutCode", [identity]))
+
+
+@jsii.data_type(
+    jsii_type="shady-island.automation.FunctionCodeUpdaterProps",
+    jsii_struct_bases=[],
+    name_mapping={"bucket": "bucket", "object_key": "objectKey", "target": "target"},
+)
+class FunctionCodeUpdaterProps:
+    def __init__(
+        self,
+        *,
+        bucket: _aws_cdk_aws_s3_ceddda9d.IBucket,
+        object_key: builtins.str,
+        target: _aws_cdk_aws_lambda_ceddda9d.IFunction,
+    ) -> None:
+        '''Constructor properties for FunctionCodeUpdater.
+
+        :param bucket: The bucket to monitor for changes.
+        :param object_key: The object within the bucket to monitor (e.g. my-application/code.zip).
+        :param target: The Lambda function to update.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__19f46ec283cf845783c22e4264d22e7ba242c3d2c1ccb328e80a86024cb13ec3)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
+            "bucket": bucket,
+            "object_key": object_key,
+            "target": target,
+        }
+
+    @builtins.property
+    def bucket(self) -> _aws_cdk_aws_s3_ceddda9d.IBucket:
+        '''The bucket to monitor for changes.'''
+        result = self._values.get("bucket")
+        assert result is not None, "Required property 'bucket' is missing"
+        return typing.cast(_aws_cdk_aws_s3_ceddda9d.IBucket, result)
+
+    @builtins.property
+    def object_key(self) -> builtins.str:
+        '''The object within the bucket to monitor (e.g. my-application/code.zip).'''
+        result = self._values.get("object_key")
+        assert result is not None, "Required property 'object_key' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def target(self) -> _aws_cdk_aws_lambda_ceddda9d.IFunction:
+        '''The Lambda function to update.'''
+        result = self._values.get("target")
+        assert result is not None, "Required property 'target' is missing"
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.IFunction, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "FunctionCodeUpdaterProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class LinuxDockerBuildProject(
     BaseDockerProject,
     metaclass=jsii.JSIIMeta,
@@ -1156,6 +1279,8 @@ __all__ = [
     "CommonDockerProps",
     "ContainerImagePipeline",
     "ContainerImagePipelineProps",
+    "FunctionCodeUpdater",
+    "FunctionCodeUpdaterProps",
     "LinuxDockerBuildProject",
     "LinuxDockerBuildProjectProps",
     "LinuxDockerManifestProject",
@@ -1226,6 +1351,32 @@ def _typecheckingstub__a82c69c46656ae83e2077c89d799ffb8536b4ddcc17b205a38a222107
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__f33a0905023521597d28cee93114601f3e35da34b9eff4df0ee5fd59350ad1e3(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    bucket: _aws_cdk_aws_s3_ceddda9d.IBucket,
+    object_key: builtins.str,
+    target: _aws_cdk_aws_lambda_ceddda9d.IFunction,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8dbf24b39a405557c0b908319842dd0572a414219a6984055ab05854fb4231eb(
+    identity: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__19f46ec283cf845783c22e4264d22e7ba242c3d2c1ccb328e80a86024cb13ec3(
+    *,
+    bucket: _aws_cdk_aws_s3_ceddda9d.IBucket,
+    object_key: builtins.str,
+    target: _aws_cdk_aws_lambda_ceddda9d.IFunction,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__909eca6f21237a8f8575d0aaa02a029242a95ef0ddf952a76fb2554f93527f99(
     scope: _constructs_77d1e7e8.Construct,
     id: builtins.str,
